@@ -12,15 +12,6 @@ from manimlib.utils.rate_functions import linear, smooth, double_smooth, exponen
 import numpy as np
 from manim_express.math import Quaternion, Vec3
 
-from custom.banner import *
-from custom.characters.pi_creature import *
-from custom.characters.pi_creature_animations import *
-from custom.characters.pi_creature_scene import *
-from custom.deprecated import *
-from custom.end_screen import *
-from custom.filler import *
-from custom.logo import *
-from custom.opening_quote import *
 
 CONFIG.preview = True
 CONFIG.color = rgb_to_hex([0.3, 0.4, 0.5]) # this will override the `color` option in custom_config.yml
